@@ -9,10 +9,10 @@ from .managers import BasisModelManager
 class BasisModel(models.Model):
     deleted = models.BooleanField(default=False)
 
-    created_at = models.DateTimeField(default=datetime.now(), auto_now_add=True)
+    created_at = models.DateTimeField(default=datetime.now, auto_now_add=True)
     created_by = models.ForeignKey(get_user_model(), null=True, default=None, related_name="%(class)s_created")
 
-    updated_at = models.DateTimeField(default=datetime.now(), auto_now=True)
+    updated_at = models.DateTimeField(default=datetime.now, auto_now=True)
     updated_by = models.ForeignKey(get_user_model(), null=True, default=None, related_name="%(class)s_updated")
 
     objects = BasisModelManager()
@@ -24,12 +24,14 @@ class BasisModel(models.Model):
     def save(self, *args, **kwargs):
 
         if 'current_user' in kwargs:
+            current_user = kwargs.pop("current_user")
+
             if not self.id:
-                self.created_by = kwargs['current_user']
+                self.created_by = current_user
 
-            self.updated_by = kwargs['current_user']
+            self.updated_by = current_user
 
-        super(BasisModel, self).save()
+        super(BasisModel, self).save(*args, **kwargs)
 
     def delete(self, *args, **kwargs):
         self.deleted = True
@@ -37,4 +39,4 @@ class BasisModel(models.Model):
 
     def restore(self, *args, **kwargs):
         self.deleted = False
-        self.save()
\ No newline at end of file
+        self.save()
